@@ -313,7 +313,7 @@ def analyse_morphologique(img_bin, img=None):
     def height(i):
         
         '''
-        compute the maximum hegth of feature with label i
+        compute the maximum height of feature with label i
         '''
         result = np.where(labeled_array == i)
         return min([img[x] for x in zip(result[0],result[1] )])
@@ -324,23 +324,23 @@ def analyse_morphologique(img_bin, img=None):
     
     if img is None:
         for i in range(1,np.max(labeled_array)+1):
-            x,y = np.where(labeled_array==i)
-            morpho[i] = [ int(np.mean(x)), 
-                          max(x)-min(x)+1, 
-                          int(np.mean(y)),
-                          max(y)-min(y)+1,
-                          np.sum(labeled_array==i)
+            y,x = np.where(labeled_array==i)
+            morpho[i] = [ int(np.mean(x)),  # x gravity center of label i
+                          max(x)-min(x)+1,  # x length of label i 
+                          int(np.mean(y)),  # y gravity center of label i
+                          max(y)-min(y)+1,  # y length of label i
+                          np.sum(labeled_array==i) # area of label i in nuber of pixels
                         ]
             df = pd.DataFrame.from_dict(morpho, orient='index',
                                columns=['x','long_x', 'y','long_y', 'size'])
     else:
         for i in range(1,np.max(labeled_array)+1):
-            x,y = np.where(labeled_array==i)
-            morpho[i] = [ int(np.mean(x)), 
-                          max(x)-min(x)+1, 
-                          int(np.mean(y)),
-                          max(y)-min(y)+1,
-                          np.sum(labeled_array==i),
+            y,x = np.where(labeled_array==i)
+            morpho[i] = [ int(np.mean(x)), # x gravity center of label i
+                          max(x)-min(x)+1, # x length of label i 
+                          int(np.mean(y)), # y gravity center of label i
+                          max(y)-min(y)+1, # y length of label i
+                          np.sum(labeled_array==i), # area of label i in nuber of pixels
                           height(i)]
 
         df = pd.DataFrame.from_dict(morpho, orient='index',
